@@ -1,11 +1,17 @@
 #!/usr/local/bin/python
 
-# ftpy is ftp clone.
-
 import ftplib,string,os
 from ftpy_define import *
 
 class ftpclient:
+
+	#Class initial
+	def __init__(self):
+		self.hostname = ""
+		self.portno = 21
+		self.user = ""
+		self.password = ""
+
 	#--------------------------------#
 	#	Member Method                #
 	#--------------------------------#
@@ -158,7 +164,7 @@ class ftpclient:
 			if pattarn == "":
 				send_command = "LIST -L"
 			else:
-				send_command = "LIST " + pattarn
+				send_command = "LIST -L " + pattarn
 			self.ftpcon.retrlines(send_command,self.remotedir_obj.append)
 			return C_OK
 		except Exception, e:
@@ -292,40 +298,78 @@ class ftpclient:
 	#Get Directory
 	def getRemoteDir(self,remote_dir,local_dir):
 		try:
-			res = self.changeRemoteDir(remote_dir)
-			if res == C_NG:
-				return C_NG
-			if local_dir[-1:] == "/":
-				mkdirpath = local_dir + remote_dir + "/"
-			else:
-				mkdirpath = local_dir + "/" + remote_dir + "/"
-			res = self.createLocalDir(mkdirpath)
-			if res == C_NG:
-				res = self.changeRemoteDir("..")
-				return C_NG
-			dir_list = []
-			self.return_msg = self.ftpcon.retrlines("LIST",dir_list.append)
-			for line in dir_list:
-				line_ent = []
-				for ent in string.split(line," "):
-					if ent <> "":
-						line_ent.append(ent)
-				if line[0] == "d":
-					if line_ent[8] <> ".." and line_ent[8] <> ".":
-						self.return_msg = self.getRemoteDir(line_ent[8],mkdirpath)
-				elif line[0] == "-":
-					localfilepath = mkdirpath + line_ent[8]
-					self.return_msg = self.getRemoteFile(line_ent[8],localfilepath)
-					if res == C_NG:
+			if self.changeRemoteDir(remote_dir) == C_OK:
+				if local_dir[-1:] == "/":
+					mkdirpath = local_dir + remote_dir + "/"
+				else:
+					mkdirpath = local_dir + "/" + remote_dir + "/"
+				if self.createLocalDir(mkdirpath) == C_OK:
+					dir_list = []
+					self.return_msg = self.ftpcon.retrlines("LIST",dir_list.append)
+					for line in dir_list:
+						line_ent = self.splitDirLine(line)
+						if line[0] == "d":
+							if line_ent[-1] <> ".." and line_ent[-1] <> ".":
+								if self.getRemoteDir(line_ent[-1],mkdirpath) == C_NG:
+									return C_NG
+						elif line[0] == "-":
+							localfilepath = mkdirpath + line_ent[-1]
+							if self.getRemoteFile(line_ent[-1],localfilepath) == C_NG:
+								return C_NG
+					if self.changeRemoteDir("..") == C_NG:
 						return C_NG
-			res = self.changeRemoteDir("..")
-			if res == C_NG:
+					return C_OK
+				else:
+					res = self.changeRemoteDir("..")
+					return C_NG
+			else:
 				return C_NG
-			return C_OK
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
 
+	#Put Local Directory
+	def putLocalDir(self,local_dir,remote_dir):
+		try:
+			if self.changeLocalDir(local_dir) == C_OK:
+				if remote_dir[-1:] == "/":
+					mkdirpath = remote_dir + local_dir + "/"
+				else:
+					mkdirpath = remote_dir + "/" + local_dir + "/"
+				if self.createRemote_dir(mkdirpath) == C_OK:
+					self.getCurrentLocalDir()
+					lcd =  self.getMsg_Obj()
+					if self.getLocalDirData(lcd[0]) == C_OK:
+						dir_list = self.getLocalDir_Obj()
+						for line in dir_list:
+							if os.path.isdir(line):
+								if line <> ".." and line <> ".":
+									if self.putLocalDir(line,mkdirpath) == C_NG:
+										return C_NG
+							elif os.path.isfile(line):
+								filepath = mkdirpath + line
+								if self.putLocalFile(filepath,line) == C_NG:
+									return C_NG
+						if self.changeLocalDir("..") == C_NG:
+							return C_NG
+						return C_OK
+					else:
+						return C_NG
+				else:
+					res = self.changeLocalDir("..")
+					return C_NG
+			else:
+				return C_NG
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	def splitDirLine(self,line):
+		line_ent = []
+		for ent in string.split(line," "):
+			if ent <> "":
+				line_ent.append(ent)
+		return line_ent
 
 	#--------------------------------#
 	#	Local Directory Control      #
@@ -407,14 +451,5 @@ class ftpclient:
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
-
-
-			
 	
-	#Class initial
-	def __init__(self):
-		self.hostname = ""
-		self.portno = 21
-		self.user = ""
-		self.password = ""
 		
