@@ -24,13 +24,11 @@ def init():
 	hostname,portno,ui,pasv,result = checkArgv()
 	if result == C_OK:
 		if hostname <> "":
-			result = checkHostname(hostname)
-			if result <> C_OK:
+			if checkHostname(hostname) <> C_OK:
 				print "Could not find server."
 				return None,None,None,None,C_NG
 		if portno <> "":
-			result = checkPortno(portno)
-			if result <> C_OK:
+			if checkPortno(portno) <> C_OK:
 				print "Portno not Integer."
 				return None,None,None,None,C_NG
 		return hostname,portno,ui,pasv,result
@@ -49,26 +47,16 @@ def checkArgv():
 		ui = C_CUI
 	elif len(sys.argv) == 2:
 		if sys.argv[1][0] == "-":
-			find_g = string.find(sys.argv[1],"g")
-			find_p = string.find(sys.argv[1],"p")
-			if find_g >= 0:
-				ui = C_GUI
-			if find_p >= 0:
-				pasv = C_ON
-			if find_g < 0 and find_p < 0:
+			ui,pasv,ret = checkOption(sys.argv[1])
+			if ret == C_NG:
 				return C_NG
 		else:
 			ui = C_CUI
 			hostname = sys.argv[1]
 	elif len(sys.argv) == 3:
 		if sys.argv[1][0] == "-":
-			find_g = string.find(sys.argv[1],"g")
-			find_p = string.find(sys.argv[1],"p")
-			if find_g >= 0:
-				ui = C_GUI
-			if find_p >= 0:
-				pasv = C_ON
-			if find_g < 0 and find_p < 0:
+			ui,pasv,ret = checkOption(sys.argv[1])
+			if ret == C_NG:
 				return C_NG
 			hostname = sys.argv[2]
 		else:
@@ -77,13 +65,8 @@ def checkArgv():
 			portno = sys.argv[2]
 	elif len(sys.argv) == 4:
 		if sys.argv[1][0] == "-":
-			find_g = string.find(sys.argv[1],"g")
-			find_p = string.find(sys.argv[1],"p")
-			if find_g >= 0:
-				ui = C_GUI
-			if find_p >= 0:
-				pasv = C_ON
-			if find_g < 0 and find_p < 0:
+			ui,pasv,ret = checkOption(sys.argv[1])
+			if ret == C_NG:
 				return C_NG
 			hostname = sys.argv[2]
 			portno = sys.argv[3]
@@ -94,6 +77,17 @@ def checkArgv():
 		
 	return hostname,portno,ui,pasv,result
 	
+#Check option
+def checkOption(argv1):
+	ui = pasv = ""
+	if string.find(argv1,"g") >= 0:
+		ui = C_GUI
+	if string.find(argv1,"p") >= 0:
+		pasv = C_ON
+	if string.find(argv1,"g") < 0 and  string.find(argv1,"p") < 0:
+		return None,None,C_NG
+	return ui,pasv,C_OK
+	
 #Check hostname
 def checkHostname(hostname):
 	try:
@@ -111,7 +105,6 @@ def checkPortno(portno):
 		result = C_NG
 
 if __name__ == "__main__":
-
 	hostname,portno,ui,pasv,result = init()
 	if result == C_OK:
 		app = ftpy(hostname,portno,ui,pasv)
